Interface _Private_LocalSymbolTable

All Superinterfaces:
SymbolTable

public interface _Private_LocalSymbolTable extends SymbolTable
  • Method Details

    • makeCopy

      Returns:
      a mutable copy of the symbol table.
    • getImportedTablesNoCopy

      SymbolTable[] getImportedTablesNoCopy()
      Returns the imported symbol tables without making a copy.

      Note: Callers must not modify the resulting SymbolTable array! This will violate the immutability property of this class.

      Returns:
      the imported symtabs, as-is; the first element is a system symtab, the rest are non-system shared symtabs
      See Also:
    • getImportedTablesAsList

      List<SymbolTable> getImportedTablesAsList()
      Returns the imported symbol tables as a List without making a copy (if possible). Like SymbolTable.getImportedTables(), the list does not include the system symbol table.
      Returns:
      the imported symbol tables. Does not include the system symbol table.
      See Also:
    • getLocalSymbolsNoCopy

      Collection<String> getLocalSymbolsNoCopy()
      Returns a collection containing the local symbols, without making a copy.
      Returns:
      the local symbols.
    • getNumberOfLocalSymbols

      int getNumberOfLocalSymbols()
      Returns:
      the number of local symbols, which do not include the imported or system symbols.