Package com.amazon.ion.impl
Interface _Private_LocalSymbolTable
- All Superinterfaces:
SymbolTable
-
Field Summary
Fields inherited from interface com.amazon.ion.SymbolTable
UNKNOWN_SYMBOL_ID -
Method Summary
Modifier and TypeMethodDescriptionReturns the imported symbol tables as a List without making a copy (if possible).Returns the imported symbol tables without making a copy.Returns a collection containing the local symbols, without making a copy.intmakeCopy()Methods inherited from interface com.amazon.ion.SymbolTable
find, findKnownSymbol, findSymbol, getImportedMaxId, getImportedTables, getIonVersionId, getMaxId, getName, getSystemSymbolTable, getVersion, intern, isLocalTable, isReadOnly, isSharedTable, isSubstitute, isSystemTable, iterateDeclaredSymbolNames, makeReadOnly, writeTo
-
Method Details
-
makeCopy
_Private_LocalSymbolTable makeCopy()- Returns:
- a mutable copy of the symbol table.
-
getImportedTablesNoCopy
SymbolTable[] getImportedTablesNoCopy()Returns the imported symbol tables without making a copy.Note: Callers must not modify the resulting SymbolTable array! This will violate the immutability property of this class.
- Returns:
- the imported symtabs, as-is; the first element is a system symtab, the rest are non-system shared symtabs
- See Also:
-
getImportedTablesAsList
List<SymbolTable> getImportedTablesAsList()Returns the imported symbol tables as a List without making a copy (if possible). LikeSymbolTable.getImportedTables(), the list does not include the system symbol table.- Returns:
- the imported symbol tables. Does not include the system symbol table.
- See Also:
-
getLocalSymbolsNoCopy
Collection<String> getLocalSymbolsNoCopy()Returns a collection containing the local symbols, without making a copy.- Returns:
- the local symbols.
-
getNumberOfLocalSymbols
int getNumberOfLocalSymbols()- Returns:
- the number of local symbols, which do not include the imported or system symbols.
-